@@ -2,10 +2,11 @@
 #define PRINTLAYOUT_H
 
 #include <QObject>
-#include <QPrinter>
 #include <QList>
 #include <QVector>
+#include <QRect>
 
+class QPrinter;
 class QTableView;
 class PrintDialog;
 class TablePrintModel;
@@ -24,8 +25,7 @@ private:
 	QPrinter *printer;
 	struct options *printOptions;
 
-	int screenDpiX, screenDpiY, printerDpi, scaledPageW, scaledPageH;
-	qreal scaleX, scaleY;
+	int screenDpiX, screenDpiY, printerDpi, pageW, pageH;
 	QRect pageRect;
 
 	QVector<QString> tablePrintColumnNames;
@@ -37,7 +37,7 @@ private:
 	void setup();
 	int estimateTotalDives() const;
 	void printProfileDives(int divesPerRow, int divesPerColumn);
-	QTableView *createProfileTable(ProfilePrintModel *model, const int tableW);
+	QTableView *createProfileTable(ProfilePrintModel *model, const int tableW, const qreal fitNotesToHeight = 0.0);
 	void printTable();
 	void addTablePrintDataRow(TablePrintModel *model, int row, struct dive *dive) const;
 	void addTablePrintHeadingRow(TablePrintModel *model, int row) const;
